builder property
A function that builds a widget tree from child and the last result of
selector.
builder will be called again whenever the its parent widget asks for an update
Must not be null.
Implementation
final ValueWidgetBuilder<T> builder;